@@ -8,13 +8,12 @@
 # Run this script
 #
 
-LANG_LIST='es fr it pt_BR'
+LANG_LIST='es fr it pt_BR zh_CN'
 
 xgettext --language=Python --keyword=_ --output=./i18n/glances.pot ./glances/glances.py
 
-for i in `echo $LANG_LIST`
-do
+for i in $LANG_LIST; do
    echo "Generate language pack for: $i"
-   msgmerge --update --no-fuzzy-matching --backup=off ./i18n/$i/LC_MESSAGES/glances.po ./i18n/glances.pot   
+   msgmerge --update --no-fuzzy-matching --backup=off ./i18n/$i/LC_MESSAGES/glances.po ./i18n/glances.pot
    msgfmt ./i18n/$i/LC_MESSAGES/glances.po --output-file ./i18n/$i/LC_MESSAGES/glances.mo
 done
